@@ -1,4 +1,5 @@
 from contextlib import contextmanager
+from importlib.util import find_spec
 from os.path import normpath
 from pprint import pformat, saferepr
 
@@ -15,6 +16,11 @@ from debug_toolbar.panels import Panel
 from debug_toolbar.panels.sql.tracking import SQLQueryTriggered, allow_sql
 from debug_toolbar.panels.templates import views
 
+if find_spec("jinja2"):
+    from debug_toolbar.panels.templates.jinja2 import patch_jinja_render
+
+    patch_jinja_render()
+
 # Monkey-patch to enable the template_rendered signal. The receiver returns
 # immediately when the panel is disabled to keep the overhead small.
 
@@ -25,7 +31,6 @@ if Template._render != instrumented_test_render:
     Template.original_render = Template._render
     Template._render = instrumented_test_render
 
-
 # Monkey-patch to store items added by template context processors. The
 # overhead is sufficiently small to justify enabling it unconditionally.
 
@@ -63,6 +68,8 @@ class TemplatesPanel(Panel):
     A panel that lists all templates used during processing of a response.
     """
 
+    is_async = True
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.templates = []
