@@ -1,10 +1,12 @@
 from pathlib import Path
 
 from django.conf import settings
-from django.contrib.staticfiles import finders
+from django.contrib.staticfiles import finders, storage
 from django.shortcuts import render
 from django.test import AsyncRequestFactory, RequestFactory
 
+from debug_toolbar.panels.staticfiles import URLMixin
+
 from ..base import BaseTestCase
 
 
@@ -76,3 +78,44 @@ class StaticFilesPanelTestCase(BaseTestCase):
         self.panel.generate_stats(self.request, response)
         self.assertEqual(self.panel.num_used, 1)
         self.assertIn('"/static/additional_static/base.css"', self.panel.content)
+
+    def test_storage_state_preservation(self):
+        """Ensure the URLMixin doesn't affect storage state"""
+        original_storage = storage.staticfiles_storage
+        original_attrs = dict(original_storage.__dict__)
+
+        # Trigger mixin injection
+        self.panel.ready()
+
+        # Verify all original attributes are preserved
+        self.assertEqual(original_attrs, dict(original_storage.__dict__))
+
+    def test_context_variable_lifecycle(self):
+        """Test the request_id context variable lifecycle"""
+        from debug_toolbar.panels.staticfiles import request_id_context_var
+
+        # Should not raise when context not set
+        url = storage.staticfiles_storage.url("test.css")
+        self.assertTrue(url.startswith("/static/"))
+
+        # Should track when context is set
+        token = request_id_context_var.set("test-request-id")
+        try:
+            url = storage.staticfiles_storage.url("test.css")
+            self.assertTrue(url.startswith("/static/"))
+            # Verify file was tracked
+            self.assertIn("test.css", [f.path for f in self.panel.used_paths])
+        finally:
+            request_id_context_var.reset(token)
+
+    def test_multiple_initialization(self):
+        """Ensure multiple panel initializations don't stack URLMixin"""
+        storage_class = storage.staticfiles_storage.__class__
+
+        # Initialize panel multiple times
+        for _ in range(3):
+            self.panel.ready()
+
+        # Verify URLMixin appears exactly once in bases
+        mixin_count = sum(1 for base in storage_class.__bases__ if base == URLMixin)
+        self.assertEqual(mixin_count, 1)
